@@ -1,6 +1,6 @@
 /* arp.c - ARP state machine */
  
-/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
+/* Written 1995-1999 by Werner Almesberger, EPFL-LRC/ICA */
  
 
 #include <stdlib.h>
@@ -118,7 +118,8 @@ static int want_arp_srv(const ITF *itf)
 	if (!vcc->connecting) return 1;
     if (itf->arp_srv->vccs) return 0;
     if ((fd = connect_vcc((struct sockaddr *) itf->arp_srv->addr,
-      &itf->arp_srv->qos,CLIP_DEFAULT_IDLETIMER)) < 0) return 0;
+      &itf->arp_srv->qos,itf->arp_srv->sndbuf,CLIP_DEFAULT_IDLETIMER)) < 0)
+	return 0;
     vcc = alloc_t(VCC);
     vcc->active = 1;
     vcc->connecting = 1;
@@ -430,7 +431,7 @@ static void connect_me(ENTRY *entry)
 
     assert(entry->addr->sas_family == AF_ATMSVC);
     if ((fd = connect_vcc((struct sockaddr *) entry->addr,&entry->qos,
-      CLIP_DEFAULT_IDLETIMER)) < 0) return;
+      entry->sndbuf,CLIP_DEFAULT_IDLETIMER)) < 0) return;
     vcc = alloc_t(VCC);
     vcc->active = 1;
     vcc->connecting = 1;
@@ -490,6 +491,7 @@ static void learn(VCC *vcc,uint32_t ip,struct sockaddr_atmsvc *addr)
 	free(vcc->entry);
 	vcc->entry = entry;
 	Q_INSERT_HEAD(entry->vccs,vcc);
+	set_sndbuf(vcc);
 	entry->flags &= ~ATF_NOVC;
 	assert(!vcc->connecting);
 	if (set_ip(vcc->fd,ip) < 0)
@@ -502,7 +504,11 @@ static void learn(VCC *vcc,uint32_t ip,struct sockaddr_atmsvc *addr)
     if (!entry)
 	if (vcc) {
 	    entry = vcc->entry;
-	    if (!entry->itf) Q_REMOVE(unknown_incoming,entry);
+	    if (!entry->itf) {
+		Q_REMOVE(unknown_incoming,entry);
+		entry->sndbuf = itf->sndbuf;
+		set_sndbuf(vcc);
+	    }
 	    else if (entry->ip && entry->ip != ip && (entry->flags & ATF_PERM)
 		  && !(entry->flags & ATF_ARPSRV)) {
 		    diag(COMPONENT,DIAG_ERROR,"ignoring attempt to change IP "
@@ -554,6 +560,7 @@ static void learn(VCC *vcc,uint32_t ip,struct sockaddr_atmsvc *addr)
 		Q_REMOVE(unknown_incoming,incoming);
 		incoming->vccs->entry = entry;
 		Q_INSERT_HEAD(entry->vccs,incoming->vccs);
+		set_sndbuf(incoming->vccs);
 		free(incoming);
 	    }
 	}
@@ -824,14 +831,15 @@ void incoming_arp(VCC *vcc,struct atmarphdr *hdr,int len)
 
 
 static int ioctl_set_pvc(ITF *itf,uint32_t ip,struct sockaddr_atmpvc *addr,
-  const struct atm_qos *qos,int flags)
+  const struct atm_qos *qos,int sndbuf,int flags)
 {
     ENTRY *entry;
     VCC *vcc;
     int fd,result;
 
     if (lookup_ip(itf,ip)) return -EEXIST; 
-    if ((fd = connect_vcc((struct sockaddr *) addr,qos,0)) < 0) return fd;
+    if ((fd = connect_vcc((struct sockaddr *) addr,qos,sndbuf,0)) < 0)
+	return fd;
     if ((result = set_ip(fd,ip)) < 0) return result;
     if (flags & ATF_NULL) {
 	if ((result = set_encap(fd,0)) < 0) return result;
@@ -841,6 +849,7 @@ static int ioctl_set_pvc(ITF *itf,uint32_t ip,struct sockaddr_atmpvc *addr,
     entry->state = as_valid;
     entry->ip = ip;
     entry->qos = *qos;
+    entry->sndbuf = sndbuf;
     entry->flags = flags;
     entry->itf = itf;
     vcc = alloc_t(VCC);
@@ -856,7 +865,7 @@ static int ioctl_set_pvc(ITF *itf,uint32_t ip,struct sockaddr_atmpvc *addr,
 
 
 static int ioctl_set_svc(ITF *itf,uint32_t ip,struct sockaddr_atmsvc *addr,
-  const struct atm_qos *qos,int flags)
+  const struct atm_qos *qos,int sndbuf,int flags)
 {
     ENTRY *entry;
 
@@ -868,6 +877,7 @@ static int ioctl_set_svc(ITF *itf,uint32_t ip,struct sockaddr_atmsvc *addr,
     entry->addr = alloc_t(struct sockaddr_atmsvc);
     *entry->addr = *addr;
     entry->qos = *qos;
+    entry->sndbuf = sndbuf;
     entry->flags = flags;
     if (!(flags & ATF_PERM) || (flags & ATF_ARPSRV))
 	if (itf->arp_srv) START_TIMER(entry,CREVAL);
@@ -914,6 +924,12 @@ static int ioctl_delete(ITF *itf,uint32_t ip,int flags)
 }
 
 
+static int qos_present(const struct atm_qos *qos)
+{
+    return qos->txtp.traffic_class || qos->rxtp.traffic_class;
+}
+
+
 int arp_ioctl(struct atmarp_req *req)
 {
     ITF *itf;
@@ -929,7 +945,8 @@ int arp_ioctl(struct atmarp_req *req)
     switch (req->type) {
 	case art_qos:
 	    diag(COMPONENT,DIAG_DEBUG,"got art_qos for itf %d",itf->number);
-	    itf->qos = req->qos;
+	    if (qos_present(&req->qos)) itf->qos = req->qos;
+	    if (req->sndbuf) itf->sndbuf = req->sndbuf;
 	    return 0;
 	case art_set:
 	    if (atm2text(buffer,MAX_ATM_ADDR_LEN+1,
@@ -940,19 +957,19 @@ int arp_ioctl(struct atmarp_req *req)
 	    diag(COMPONENT,DIAG_DEBUG,"got art_set for itf %d, IP %d.%d.%d.%d"
 	      ", ATM %s, flags 0x%x",itf->number,ipp[0],ipp[1],ipp[2],ipp[3],
 	      buffer,req->flags);
-	    if (!req->qos.txtp.traffic_class && !req->qos.rxtp.traffic_class)
-		req->qos = itf->qos;
+	    if (!qos_present(&req->qos)) req->qos = itf->qos;
+	    if (!req->sndbuf) req->sndbuf = itf->sndbuf;
 	    switch (req->addr.sas_family) {
 		case AF_ATMPVC:	
 		    adjust_qos(itf,&req->qos,req->flags & ATF_NULL);
 		    return ioctl_set_pvc(itf,req->ip,
 		      (struct sockaddr_atmpvc *) &req->addr,&req->qos,
-		      req->flags);
+		      req->sndbuf,req->flags);
 		case AF_ATMSVC:
 		    adjust_qos(itf,&req->qos,0);
 		    return ioctl_set_svc(itf,req->ip,
 		      (struct sockaddr_atmsvc *) &req->addr,&req->qos,
-		      req->flags);
+		      req->sndbuf,req->flags);
 		default: /* not reached - atm2text complains before */
 		    diag(COMPONENT,DIAG_ERROR,"art_set: bad HA AF 0x%x",
 		      req->addr.sas_family);
