@@ -98,7 +98,7 @@ static void dump_vcc(VCC *vcc)
     char addr_buf[MAX_ATM_ADDR_LEN+1];
     char qos_buf[MAX_ATM_QOS_LEN+1];
     struct atm_qos qos;
-    int size;
+    int size,sndbuf;
 
     size = sizeof(addr);
     if (getpeername(vcc->fd,(struct sockaddr *) &addr,&size) < 0) {
@@ -122,13 +122,17 @@ static void dump_vcc(VCC *vcc)
     if (vcc->connecting) return;
     size = sizeof(qos);
     if (getsockopt(vcc->fd,SOL_ATM,SO_ATMQOS,&qos,&size) < 0)
-	sprintf(qos_buf,"<no qos: %s>",strerror(errno));
-    else {
-	if (vcc->entry && qos_equal(&vcc->entry->qos,&qos)) return;
-	if (qos2text(qos_buf,sizeof(qos_buf),&qos,0) < 0)
+	output("    QOS: <unavailable: %s>",strerror(errno));
+    else if (!vcc->entry || !qos_equal(&vcc->entry->qos,&qos)) {
+	    if (qos2text(qos_buf,sizeof(qos_buf),&qos,0) < 0)
 	    strcpy(qos_buf,"<invalid qos>");
-	output("    QOS: %s",qos_buf);
-    }
+	    output("    QOS: %s",qos_buf);
+	}
+    size = sizeof(sndbuf);
+    if (getsockopt(vcc->fd,SOL_SOCKET,SO_SNDBUF,&sndbuf,&size) < 0)
+	output("    Send buffer: <unavailable: %s>",strerror(errno));
+    else if (!vcc->entry || vcc->entry->sndbuf != sndbuf)
+	    output("    Send buffer: %d",sndbuf);
 }
 
 
@@ -176,6 +180,8 @@ static void dump_entries(ENTRY *list)
 		strcpy(qos_buf,"<error>");
 	    output("  QOS: %s",qos_buf);
 	}
+	if (entry->itf && entry->sndbuf && entry->sndbuf != entry->itf->sndbuf)
+	    output("  Send buffer: %d",entry->sndbuf);
 	if (entry->notify) {
 	    NOTIFY *notify;
 	    int count;
@@ -194,12 +200,13 @@ static void dump_itf(ITF *itf)
     unsigned char *ipp,*nmp;
     char buf[MAX_ATM_QOS_LEN+1];
 
-    if (qos2text(buf,sizeof(buf),&itf->qos,0) < 0) strcpy(buf,"<error>");
     ipp = (unsigned char *) &itf->local_ip;
     nmp = (unsigned char *) &itf->netmask;
     output("----- Itf %d (%d.%d.%d.%d, netmask %d.%d.%d.%d) -----",itf->number,
       ipp[0],ipp[1],ipp[2],ipp[3],nmp[0],nmp[1],nmp[2],nmp[3]);
+    if (qos2text(buf,sizeof(buf),&itf->qos,0) < 0) strcpy(buf,"<error>");
     output("Default QOS: %s",buf);
+    if (itf->sndbuf) output("Default send buffer: %d",itf->sndbuf);
     dump_entries(itf->table);
 }
 
