@@ -18,13 +18,14 @@
 typedef struct {
   const Unit_t *unit;
   unsigned int alarm_time;
-  const void *data;
+  void *data;
 } Timer_t;
 
 /* Global function prototypes */
 Timer_t *timer_new(const Unit_t *unit);
 void timer_free(const Unit_t *unit, Timer_t *timer);
-void timer_alarm(const Unit_t *unit, Timer_t *timer, unsigned int nsecs, const void *data);
+void timer_alarm(const Unit_t *unit, Timer_t *timer, unsigned int nsecs, 
+		 void *data);
 void timer_ack(const Unit_t *unit, Timer_t *timer);
 Timer_t *timer_find_soonest(const Unit_t *unit);
 
