@@ -1,7 +1,7 @@
 /* text2qos.c - Converts textual representation of QOS parameters to binary
 		encoding */
 
-/* Written 1996-1998 by Werner Almesberger, EPFL-LRC/ICA */
+/* Written 1996-1999 by Werner Almesberger, EPFL-LRC/ICA */
 
 
 #include <stdlib.h>
@@ -19,7 +19,7 @@
 #define RATE_ERROR -2
 
 
-static int get_rate(const char **text,int up)
+int __t2q_get_rate(const char **text,int up)
 {
     const char mult[] = "kKmMgGg";
     const char *multiplier;
@@ -86,17 +86,17 @@ static int params(const char **text,struct atm_trafprm *a,
 	switch (fetch(text,"max_pcr=","pcr=","min_pcr=","max_sdu=","sdu=",
 	  NULL)) {
 	    case 0:
-		if ((value = get_rate(text,0)) == RATE_ERROR) return -1;
+		if ((value = __t2q_get_rate(text,0)) == RATE_ERROR) return -1;
 		if (a) a->max_pcr = value;
 		if (b) b->max_pcr = value;
 		break;
 	    case 1:
-		if ((value = get_rate(text,0)) == RATE_ERROR) return -1;
+		if ((value = __t2q_get_rate(text,0)) == RATE_ERROR) return -1;
 		if (a) a->pcr = value;
 		if (b) b->pcr = value;
 		break;
 	    case 2:
-		if ((value = get_rate(text,1)) == RATE_ERROR) return -1;
+		if ((value = __t2q_get_rate(text,1)) == RATE_ERROR) return -1;
 		if (value == ATM_MAX_PCR) return -1;
 		if (a) a->min_pcr = value;
 		if (b) b->min_pcr = value;
