@@ -1,6 +1,6 @@
 /* atmdiag.c - ATM diagnostics */
 
-/* Written 1995,1996,1998 by Werner Almesberger, EPFL-LRC/ICA */
+/* Written 1995-1999 by Werner Almesberger, EPFL-LRC/ICA */
 
 
 #include <stdlib.h>
@@ -43,9 +43,9 @@ static void display(int s,int itf,int zero)
 	  );
 	first = 0;
     }
-    printf("%3d AAL0  %8ld  %8ld  %8ld  %8ld  %8ld\n",itf,stats.aal0.tx,
+    printf("%3d AAL0  %8d  %8d  %8d  %8d  %8d\n",itf,stats.aal0.tx,
       stats.aal0.tx_err,stats.aal0.rx,stats.aal0.rx_err,stats.aal0.rx_drop);
-    printf("%3s AAL5  %8ld  %8ld  %8ld  %8ld  %8ld\n","",stats.aal5.tx,
+    printf("%3s AAL5  %8d  %8d  %8d  %8d  %8d\n","",stats.aal5.tx,
       stats.aal5.tx_err,stats.aal5.rx,stats.aal5.rx_err,stats.aal5.rx_drop);
 }
 
