@@ -1,6 +1,6 @@
 /* atmtcp.c - control ATM on TCP emulation */
 
-/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
+/* Written 1995-1999 by Werner Almesberger, EPFL-LRC/ICA */
 
 
 #include <stdlib.h>
@@ -24,6 +24,10 @@
 			   network byte order, so we're incompatible in most
 			   cases */
 
+/* IANA port number assignment pending. Include control messages in
+   network protocol when changing port number. */
+
+
 #define MAX_PACKET ATM_MAX_AAL5_PDU+sizeof(struct atmtcp_hdr)
 
 
@@ -31,7 +35,7 @@ static int s_tcp,s_krn;
 static int debug = 0;
 
 
-static void net_write(void *data,int size)
+static void net_write(const void *data,int size)
 {
     int wrote;
 
@@ -48,6 +52,38 @@ static void net_write(void *data,int size)
 }
 
 
+static void kernel_write(const void *data,int size)
+{
+    int wrote;
+
+    wrote = write(s_krn,data,size);
+    if (wrote < 0) perror("write to kernel");
+    else if (wrote != size) {
+	    fprintf(stderr,"bad write (%d != %d)\n",wrote,size);
+	    exit(1);
+	}
+}
+
+
+static void control(struct atmtcp_control *msg)
+{
+    if (debug)
+	switch (msg->type) {
+	    case ATMTCP_CTRL_OPEN:
+		fprintf(stderr,"OPEN %d.%d, vcc 0x%08lx\n",
+		  msg->addr.sap_addr.vpi,msg->addr.sap_addr.vci,msg->vcc);
+		break;
+	    case ATMTCP_CTRL_CLOSE:
+		fprintf(stderr,"CLOSE vcc 0x%08lx\n",msg->vcc);
+		break;
+	    default:
+		fprintf(stderr,"Unknown control message type %d\n",msg->type);
+		return;
+	}
+    kernel_write(msg,sizeof(*msg));
+}
+
+
 /*
  * This is a pretty poor implementation because we need to read twice for each
  * PDU. But then, atmtcp isn't exactly designed for throughput ...
@@ -80,12 +116,7 @@ static void from_tcp(void)
     if (debug)
 	fprintf(stderr,"TCP %d.%d, %d bytes\n",ntohs(hdr->vpi),ntohs(hdr->vci),
 	  (unsigned int) ntohl(hdr->length));
-    size = write(s_krn,buf,bytes);
-    if (size < 0) perror("write to kernel");
-    else if (size != bytes) {
-	    fprintf(stderr,"bad write (%d != %d)\n",size,bytes);
-	    exit(1);
-	}
+    kernel_write(buf,bytes);
     bytes = 0;
 }
 
@@ -106,6 +137,14 @@ static void to_tcp(void)
 	fprintf(stderr,"kernel message too small (%d)\n",ret);
 	exit(1);
     }
+    if (hdr->length == ATMTCP_HDR_MAGIC) {
+	if (ret < sizeof(struct atmtcp_control)) {
+	    fprintf(stderr,"invalid control message\n");
+	    exit(1);
+	}
+	control((struct atmtcp_control *) buf);
+	return;
+    }
     if (debug)
 	fprintf(stderr,"KRN %d.%d, %d bytes\n",ntohs(hdr->vpi),ntohs(hdr->vci),
 	  (unsigned int) ntohl(hdr->length));
