@@ -174,7 +174,8 @@ static void dump_status(FILE *file,const char *banner)
     for (sig = entities; sig; sig = sig->next) {
 	fprintf(file,"--- Entity %d.%d.%d ---\n",S_PVC(sig));
 	for (walk = sockets; walk; walk = walk->next) {
-	    fprintf(file,"0x%lx: %s, CR 0x%06lX, PVC %d.%d.%d\n",walk->id,
+	    fprintf(file,"0x%lx: %s, CR 0x%06lX, PVC %d.%d.%d\n",
+	      (unsigned long) walk->id,
 	      state_name[walk->state],walk->call_ref,walk->pvc.sap_addr.itf,
 	      walk->pvc.sap_addr.vpi,walk->pvc.sap_addr.vci);
 	    dump_addr(file,"local ",&walk->local);
