@@ -94,7 +94,8 @@ void to_kernel(struct atmsvc_msg *msg)
     int wrote;
 
     diag("KERNEL",DIAG_DEBUG,"TO KERNEL: %s (%d) for 0x%lx/0x%lx",
-      as_name[msg->type],msg->reply,msg->vcc,msg->listen_vcc);
+      as_name[msg->type],msg->reply,(unsigned long) msg->vcc,
+      (unsigned long) msg->listen_vcc);
 	/* should be "IO" ... */
     trace_kernel("TO KERNEL",msg);
     wrote = write(kernel,msg,sizeof(*msg));
