@@ -75,7 +75,7 @@ typedef struct _socket {
     SIG_ENTITY *sig;
     struct sockaddr_atmpvc pvc;
     /* --- socket layer information ---------------------------------------- */
-    unsigned long id;
+    atm_kptr_int_t id;
     struct sockaddr_atmsvc local; /* local address */
     struct sockaddr_atmsvc remote; /* remote address */
     struct atm_sap sap; /* SAP (BHLI and BLLI) */
@@ -137,7 +137,7 @@ void from_kernel(struct atmsvc_msg *msg,int size);
 void sync_addr(VPCI *vpci);
 
 void to_uni(SIG_ENTITY *sig,void *msg,int size);
-void send_kernel(unsigned long vcc,unsigned long listen_vcc,
+void send_kernel(atm_kptr_int_t vcc,atm_kptr_int_t listen_vcc,
   enum atmsvc_msg_type type,int reply,const struct sockaddr_atmpvc *pvc,
   const struct sockaddr_atmsvc *svc,const struct sockaddr_atmsvc *local,
   const struct atm_sap *sap,const struct atm_qos *qos);
@@ -148,7 +148,7 @@ void saal_okay(SIG_ENTITY *sig);
 void clear_all_calls(SIG_ENTITY *sig);
 void clear_all_calls_on_T309(SIG_ENTITY *sig);
 
-SOCKET *new_sock(unsigned long id);
+SOCKET *new_sock(atm_kptr_int_t id);
 void free_sock(SOCKET *sock);
 void new_state(SOCKET *sock,STATE state);
 SOCKET *lookup_sap(const struct sockaddr_atmsvc *addr,
