@@ -6,8 +6,8 @@
 #include <stdlib.h>
 #include <string.h>
 #include <errno.h>
+#include <stdint.h> /* linux/atmdev and linux/atmsvc.h include linux/atm.h */
 #include <linux/atmdev.h>
-#include <stdint.h> /* sigh, again */
 #include <linux/atmsvc.h>
 
 #include "atm.h"
