@@ -1,6 +1,6 @@
 /* trace.c - Support functions for message tracing */
  
-/* Written 1996-1998 by Werner Almesberger, EPFL-LRC/ICA */
+/* Written 1996-1999 by Werner Almesberger, EPFL-LRC/ICA */
  
 
 #include <stdlib.h>
@@ -185,8 +185,9 @@ static void print_kernel(void *msg,int size)
       "as_close","as_itf_notify","as_modify","as_identify" };
     struct atmsvc_msg *m = msg;
 
-    append("  %s (vcc 0x%x, listen_vcc 0x%x)\n",m->type < sizeof(type)/
-      sizeof(*type) ? type[m->type] : "???",m->vcc,m->listen_vcc);
+    append("  %s (vcc 0x%lx, listen_vcc 0x%lx)\n",m->type < sizeof(type)/
+      sizeof(*type) ? type[m->type] : "???",(unsigned long) m->vcc,
+      (unsigned long) m->listen_vcc);
     append("  reply %d",m->reply);
     if (m->reply) {
 	const char *error;
